#[non_exhaustive]pub enum CfgPathError {
UnknownVar(String),
NoProjectDirs,
NoBaseDirs,
NoProgramPath,
NoProgramDir,
InvalidString(String),
VariableInterpolationNotSupported(String),
HomeDirInterpolationNotSupported(String),
}Expand description
An error that has occurred while expanding a path.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownVar(String)
The path contained a variable we didn’t recognize.
NoProjectDirs
We couldn’t construct a ProjectDirs object.
NoBaseDirs
We couldn’t construct a BaseDirs object.
NoProgramPath
We couldn’t find our current binary path.
NoProgramDir
We couldn’t find the directory path containing the current binary.
InvalidString(String)
We couldn’t convert a string to a valid path on the OS.
VariableInterpolationNotSupported(String)
Variable interpolation ($) attempted, but not compiled in
HomeDirInterpolationNotSupported(String)
Home dir interpolation (~) attempted, but not compiled in