ArtiKeystoreConfigBuilder

Struct ArtiKeystoreConfigBuilder 

pub struct ArtiKeystoreConfigBuilder { /* private fields */ }
A builder to create an instance of ArtiKeystoreConfig.

Implementations

Source

impl ArtiKeystoreConfigBuilder

pub fn enabled(&mut self, val: BoolOrAuto) -> &mut Self

Provide a value for enabled.

If no value is provided for enabled, build will use Default::default().

enabled

Whether keystore use is enabled.

pub fn primary(&mut self) -> &mut PrimaryKeystoreConfigBuilder

Return a mutable reference to the inner builder for primary.

primary

The primary keystore.

pub fn ctor(&mut self) -> &mut CTorKeystoreConfigBuilder

Return a mutable reference to the inner builder for ctor.

ctor

Optionally configure C Tor keystores for arti to use.

Note: The keystores listed here are read-only (keys are only ever written to the primary keystore, configured in storage.keystore.primary).

Each C Tor keystore must have a unique identifier. It is an error to configure multiple keystores with the same KeystoreId.

Source

impl ArtiKeystoreConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<ArtiKeystoreConfig, ConfigBuildError>

Try to construct a new ArtiKeystoreConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.

Source

impl ArtiKeystoreConfigBuilder

pub fn ctor_service( &mut self, builder: CTorServiceKeystoreConfigBuilder, ) -> &mut Self

Add a CTorServiceKeystoreConfigBuilder to this builder.