pub struct CTorClientKeystoreConfig {
id: KeystoreId,
path: PathBuf,
}Expand description
C Tor ArtiNativeKeystore configuration
Fields
id: KeystoreIdThe identifier of this keystore.
Each keystore must have a unique identifier.
It is an error to configure multiple keystores with the same KeystoreId.
path: PathBufThe root directory of this keystore.
This should be set to the ClientOnionAuthDir of your client.
If Arti is configured to run as a client (i.e. if it runs in SOCKS proxy mode),
it will read the client restricted discovery keys from this path.
The key files are expected to have the .auth_private extension,
and their content must be of the form:
<56-char-onion-addr-without-.onion-part>:descriptor:x25519:<x25519 private key in base32>.
Malformed files, and files that don’t have the .auth_private extension, will be ignored.
Implementations
Sourceimpl CTorClientKeystoreConfig
impl CTorClientKeystoreConfig
Sourcepub fn builder() -> CTorClientKeystoreConfigBuilder
pub fn builder() -> CTorClientKeystoreConfigBuilder
Return a new [CTorClientKeystoreConfig Builder] to construct an instance of this type.
Sourceimpl CTorClientKeystoreConfig
impl CTorClientKeystoreConfig
Sourcepub fn id(&self) -> &KeystoreId
pub fn id(&self) -> &KeystoreId
Method borrowing CTorClientKeystoreConfig::id field.
The identifier of this keystore.
Sourcepub fn path(&self) -> &PathBuf
pub fn path(&self) -> &PathBuf
Method borrowing CTorClientKeystoreConfig::path field.
The root directory of this keystore.