CTorClientKeystoreConfigBuilder

Struct CTorClientKeystoreConfigBuilder 

pub struct CTorClientKeystoreConfigBuilder { /* private fields */ }
A builder to create an instance of CTorClientKeystoreConfig.

Implementations

Source

impl CTorClientKeystoreConfigBuilder

pub fn id(&mut self, val: KeystoreId) -> &mut Self

Provide a value for id.

If no value is provided for id, build will fail with an error.

id

The identifier of this keystore.

Each keystore must have a unique identifier. It is an error to configure multiple keystores with the same KeystoreId.

pub fn path(&mut self, val: PathBuf) -> &mut Self

Provide a value for path.

If no value is provided for path, build will fail with an error.

path

The root directory of this keystore.

This should be set to the ClientOnionAuthDir of your client. If Arti is configured to run as a client (i.e. if it runs in SOCKS proxy mode), it will read the client restricted discovery keys from this path.

The key files are expected to have the .auth_private extension, and their content must be of the form: <56-char-onion-addr-without-.onion-part>:descriptor:x25519:<x25519 private key in base32>.

Malformed files, and files that don’t have the .auth_private extension, will be ignored.

Source

impl CTorClientKeystoreConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<CTorClientKeystoreConfig, ConfigBuildError>

Try to construct a new CTorClientKeystoreConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.