pub struct CTorKeystoreConfigBuilder { /* private fields */ }Expand description
A builder to create an instance of CTorKeystoreConfig.
Implementations
Sourceimpl CTorKeystoreConfigBuilder
impl CTorKeystoreConfigBuilder
Sourcepub fn services(&mut self) -> &mut CTorServiceKeystoreConfigMapBuilder
pub fn services(&mut self) -> &mut CTorServiceKeystoreConfigMapBuilder
Return a mutable reference to the inner builder for services.
services
C Tor hidden service keystores.
Sourcepub fn clients(&mut self) -> &mut CTorClientKeystoreConfigListBuilder
pub fn clients(&mut self) -> &mut CTorClientKeystoreConfigListBuilder
Return a mutable reference to the inner builder for clients.
clients
C Tor hidden service client keystores.
Sourceimpl CTorKeystoreConfigBuilder
impl CTorKeystoreConfigBuilder
Sourcepub fn build(&self) -> Result<CTorKeystoreConfig, ConfigBuildError>
pub fn build(&self) -> Result<CTorKeystoreConfig, ConfigBuildError>
Try to construct a new CTorKeystoreConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl CTorKeystoreConfigBuilder
impl CTorKeystoreConfigBuilder
Sourcepub fn ctor_service(
&mut self,
builder: CTorServiceKeystoreConfigBuilder,
) -> &mut Self
pub fn ctor_service( &mut self, builder: CTorServiceKeystoreConfigBuilder, ) -> &mut Self
Add a CTorServiceKeystoreConfigBuilder to this builder.