pub struct CTorServiceKeystoreConfig {
id: KeystoreId,
path: PathBuf,
nickname: HsNickname,
}Expand description
C Tor ArtiNativeKeystore configuration
Fields
id: KeystoreIdThe identifier of this keystore.
Each C Tor keystore must:
- have a unique identifier. It is an error to configure multiple keystores
with the same
KeystoreId. - have a corresponding arti hidden service configured in the
[onion_services]section with the same nickname
path: PathBufThe root directory of this keystore.
This should be set to the HiddenServiceDirectory of your hidden service.
Arti will read HiddenServiceDirectory/hostname and HiddenServiceDirectory/private_key.
(Note: if your service is running in restricted discovery mode, you must also set the
[[onion_services."<the nickname of your svc>".restricted_discovery.key_dirs]]
to HiddenServiceDirectory/client_keys).
nickname: HsNicknameThe nickname of the service this keystore is to be used with.
Implementations
Sourceimpl CTorServiceKeystoreConfig
impl CTorServiceKeystoreConfig
Sourcepub fn builder() -> CTorServiceKeystoreConfigBuilder
pub fn builder() -> CTorServiceKeystoreConfigBuilder
Return a new [CTorServiceKeystoreConfig Builder] to construct an instance of this type.
Sourceimpl CTorServiceKeystoreConfig
impl CTorServiceKeystoreConfig
Sourcepub fn id(&self) -> &KeystoreId
pub fn id(&self) -> &KeystoreId
Method borrowing CTorServiceKeystoreConfig::id field.
The identifier of this keystore.
Sourcepub fn path(&self) -> &PathBuf
pub fn path(&self) -> &PathBuf
Method borrowing CTorServiceKeystoreConfig::path field.
The root directory of this keystore.
Sourcepub fn nickname(&self) -> &HsNickname
pub fn nickname(&self) -> &HsNickname
Method borrowing CTorServiceKeystoreConfig::nickname field.
The nickname of the service this keystore is to be used with.