CTorServiceKeystoreConfigBuilder

Struct CTorServiceKeystoreConfigBuilder 

pub struct CTorServiceKeystoreConfigBuilder { /* private fields */ }
A builder to create an instance of CTorServiceKeystoreConfig.

Implementations

Source

impl CTorServiceKeystoreConfigBuilder

pub fn id(&mut self, val: KeystoreId) -> &mut Self

Provide a value for id.

If no value is provided for id, build will fail with an error.

id

The identifier of this keystore.

Each C Tor keystore must:

  • have a unique identifier. It is an error to configure multiple keystores with the same KeystoreId.
  • have a corresponding arti hidden service configured in the [onion_services] section with the same nickname
pub fn path(&mut self, val: PathBuf) -> &mut Self

Provide a value for path.

If no value is provided for path, build will fail with an error.

path

The root directory of this keystore.

This should be set to the HiddenServiceDirectory of your hidden service. Arti will read HiddenServiceDirectory/hostname and HiddenServiceDirectory/private_key. (Note: if your service is running in restricted discovery mode, you must also set the [[onion_services."<the nickname of your svc>".restricted_discovery.key_dirs]] to HiddenServiceDirectory/client_keys).

pub fn nickname(&mut self, val: HsNickname) -> &mut Self

Provide a value for nickname.

If no value is provided for nickname, build will fail with an error.

nickname

The nickname of the service this keystore is to be used with.

Source

impl CTorServiceKeystoreConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<CTorServiceKeystoreConfig, ConfigBuildError>

Try to construct a new CTorServiceKeystoreConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.