RawKeySpecifierComponentParser

Trait RawKeySpecifierComponentParser 

pub trait RawKeySpecifierComponentParser {
    // Required method
    fn parse(&mut self, comp: &Slug) -> RawComponentParseResult;
}
Trait for parsing a path component, used by parse_arti_path

Implemented for Option<impl KeySpecifierComponent>, and guarantees to fill in the Option if it succeeds.

Also implemented for &str: just checks that the string is right, (and, doesn’t modify *self).

Required Methods

fn parse(&mut self, comp: &Slug) -> RawComponentParseResult

Check that comp is as expected, and store any results in self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'s> RawKeySpecifierComponentParser for &'s str

Source

fn parse(&mut self, comp: &Slug) -> RawComponentParseResult

Source

impl<T: KeySpecifierComponent> RawKeySpecifierComponentParser for Option<T>

Source

fn parse(&mut self, comp: &Slug) -> RawComponentParseResult

Implementors