pub struct KeyPathInfoBuilder {
summary: Option<String>,
role: Option<String>,
extra_info: Option<BTreeMap<String, String>>,
}Expand description
Builder for KeyPathInfo.
Fields
summary: Option<String>A human-readable summary string describing what the KeyPath is for.
This should not recapitulate information in the extra_info.
role: Option<String>The key role, ie its official name in the Tor Protocols.
This should usually start with KS_.
extra_info: Option<BTreeMap<String, String>>Additional information, in the form of key-value pairs.
This will contain human-readable information that describes the individual
components of a KeyPath. For example, for the ArtiPath
hs/foo/KS_hs_id.expanded_ed25519_private, the extra information could
be ("kind", "service), ("nickname", "foo"), etc.
Implementations
Sourceimpl KeyPathInfoBuilder
impl KeyPathInfoBuilder
Sourcepub fn summary(&mut self, value: String) -> &mut Self
pub fn summary(&mut self, value: String) -> &mut Self
A human-readable summary string describing what the KeyPath is for.
This should not recapitulate information in the extra_info.
Sourcepub fn role(&mut self, value: String) -> &mut Self
pub fn role(&mut self, value: String) -> &mut Self
The key role, ie its official name in the Tor Protocols.
This should usually start with KS_.
Sourcepub fn build(&self) -> Result<KeyPathInfo, KeyPathInfoBuilderError>
pub fn build(&self) -> Result<KeyPathInfo, KeyPathInfoBuilderError>
Sourcefn create_empty() -> Self
fn create_empty() -> Self
Create an empty builder, with all fields set to None or PhantomData.
Sourceimpl KeyPathInfoBuilder
impl KeyPathInfoBuilder
Sourcepub fn set_all_extra_info(
&mut self,
all_extra_info: impl Iterator<Item = (String, String)>,
) -> &mut Self
pub fn set_all_extra_info( &mut self, all_extra_info: impl Iterator<Item = (String, String)>, ) -> &mut Self
Initialize the additional information of this builder with the specified values.
Erases the preexisting extra_info.