pub(super) struct UnparsedCert {
inner: Vec<u8>,
path: PathBuf,
}Expand description
An unparsed key certificate.
Fields
inner: Vec<u8>The contents of the cert file.
path: PathBufThe path of the file (for error reporting).
Implementations
Sourceimpl UnparsedCert
impl UnparsedCert
Sourcepub(super) fn parse_certificate_erased(
self,
cert_type: &CertType,
) -> Result<ErasedKey>
pub(super) fn parse_certificate_erased( self, cert_type: &CertType, ) -> Result<ErasedKey>
Parse a key certificate, converting the key material into a known type, and return the type-erased value.
The caller is expected to downcast the value returned to a concrete type.