pub(crate) enum MalformedPathError {
Utf8,
NoExtension,
InvalidArtiPath(ArtiPathSyntaxError),
}Expand description
The keystore contained a file whose name syntactically improper
Keys are supposed to have pathnames consisting of an ArtiPath
followed by a file extension.
See also KeyPathError, which occurs at a higher level.
Variants
Utf8
Found a key with a non-UTF-8 path.
NoExtension
Found a key with no extension.
InvalidArtiPath(ArtiPathSyntaxError)
The file path is not a valid ArtiPath.