pub(super) struct UnparsedOpenSshKey {
inner: Zeroizing<String>,
path: PathBuf,
}Expand description
An unparsed OpenSSH key.
Note: This is a wrapper around the contents of a file we think is an OpenSSH key. The inner value is unchecked/unvalidated, and might not actually be a valid OpenSSH key.
The inner value is zeroed on drop.
Fields
inner: Zeroizing<String>The contents of an OpenSSH key file.
path: PathBufThe path of the file (for error reporting).
Implementations
Sourceimpl UnparsedOpenSshKey
impl UnparsedOpenSshKey
Sourcepub(crate) fn new(inner: String, path: PathBuf) -> Self
pub(crate) fn new(inner: String, path: PathBuf) -> Self
Create a new UnparsedOpenSshKey.
The contents of inner are erased on drop.
Sourcepub(crate) fn parse_ssh_format_erased(
self,
key_type: &KeyType,
) -> Result<ErasedKey>
pub(crate) fn parse_ssh_format_erased( self, key_type: &KeyType, ) -> Result<ErasedKey>
Parse an OpenSSH key, convert the key material into a known key type, and return the type-erased value.
The caller is expected to downcast the value returned to a concrete type.