pub struct KeystoreEntry<'a> {
key_path: KeyPath,
key_type: KeystoreItemType,
keystore_id: &'a KeystoreId,
raw_id: RawEntryId,
}Expand description
A keystore entry descriptor.
This identifies a key entry from a specific keystore.
The key entry can be retrieved, using KeyMgr::get_entry,
or removed, using KeyMgr::remove_entry.
Returned from KeyMgr::list_matching.
Fields
key_path: KeyPathThe KeyPath of the key.
key_type: KeystoreItemTypeThe KeystoreItemType of the key.
keystore_id: &'a KeystoreIdThe KeystoreId of the keystore where the key was found.
raw_id: RawEntryIdThe RawEntryId of the key, an identifier used in
arti raw operations.
Implementations
Sourceimpl<'a> KeystoreEntry<'a>
impl<'a> KeystoreEntry<'a>
Sourcepub fn key_path(&self) -> &KeyPath
pub fn key_path(&self) -> &KeyPath
Method borrowing KeystoreEntry::key_path field.
The KeyPath of the key.
Sourcepub fn key_type(&self) -> &KeystoreItemType
pub fn key_type(&self) -> &KeystoreItemType
Method borrowing KeystoreEntry::key_type field.
The KeystoreItemType of the key.
Sourcepub fn keystore_id(&self) -> &'a KeystoreId
pub fn keystore_id(&self) -> &'a KeystoreId
Method returning copy of KeystoreEntry::keystore_id field.
The KeystoreId of the keystore where the key was found.
Sourceimpl<'a> KeystoreEntry<'a>
impl<'a> KeystoreEntry<'a>
Sourcepub(crate) fn new(
key_path: KeyPath,
key_type: KeystoreItemType,
keystore_id: &'a KeystoreId,
raw_id: RawEntryId,
) -> Self
pub(crate) fn new( key_path: KeyPath, key_type: KeystoreItemType, keystore_id: &'a KeystoreId, raw_id: RawEntryId, ) -> Self
Create a new KeystoreEntry
Sourcepub fn raw_entry(&self) -> RawKeystoreEntry
pub fn raw_entry(&self) -> RawKeystoreEntry
Return an instance of RawKeystoreEntry