pub struct UnrecognizedEntry { /* private fields */ }Expand description
The opaque identifier of an unrecognized key inside a Keystore.
Implementations
Sourceimpl UnrecognizedEntry
impl UnrecognizedEntry
Sourcepub fn raw_id(&self) -> &RawEntryId
pub fn raw_id(&self) -> &RawEntryId
Method borrowing UnrecognizedEntry::raw_id field.
The RawEntryId of the key, an identifier used in arti raw operations.
Sourcepub fn keystore_id(&self) -> &KeystoreId
pub fn keystore_id(&self) -> &KeystoreId
Method borrowing UnrecognizedEntry::keystore_id field.
The KeystoreId of the keystore where the entry was found.