pub trait KeyCertificateSpecifier {
// Required methods
fn cert_denotators(&self) -> Vec<&dyn KeySpecifierComponent>;
fn subject_key_specifier(&self) -> &dyn KeySpecifier;
}Expand description
The “specifier” of a key certificate, which identifies an instance of a cert, as well as its signing and subject keys.
Certificates can only be fetched from Arti key stores (we will not support loading certs from C Tor’s key directory)
Types implementing this trait get an auto-generated KeySpecifier implementation
that returns the ArtiPath of the certificate.
The generated KeySpecifier::arti_path() returns
- the
ArtiPathof theKeyCertificateSpecifier::subject_key_specifier, ifKeyCertificateSpecifier::cert_denotatorsis empty, or - the
ArtiPathof theKeyCertificateSpecifier::subject_key_specifier, followed by aDENOTATOR_GROUP_SEPcharacter and theKeyCertificateSpecifier::cert_denotatorsencoded as described in theArtiPathdocs, ifKeyCertificateSpecifier::cert_denotatorsis non-empty
Required Methods
Sourcefn cert_denotators(&self) -> Vec<&dyn KeySpecifierComponent>
fn cert_denotators(&self) -> Vec<&dyn KeySpecifierComponent>
The denotators of the certificate.
Used by KeyMgr to derive the ArtiPath of the certificate.
The ArtiPath of a certificate is obtained
by concatenating the ArtiPath of the subject key with the
denotators provided by this function,
with a + between the ArtiPath of the subject key and
the denotators (the + is omitted if there are no denotators).
Sourcefn subject_key_specifier(&self) -> &dyn KeySpecifier
fn subject_key_specifier(&self) -> &dyn KeySpecifier
The key specifier of the subject key.