pub struct ArtiKeystoreConfigBuilder { /* private fields */ }Expand description
A builder to create an instance of ArtiKeystoreConfig.
Implementations
Sourceimpl ArtiKeystoreConfigBuilder
impl ArtiKeystoreConfigBuilder
Sourcepub fn enabled(&mut self, val: BoolOrAuto) -> &mut Self
pub fn enabled(&mut self, val: BoolOrAuto) -> &mut Self
Sourcepub fn primary(&mut self) -> &mut PrimaryKeystoreConfigBuilder
pub fn primary(&mut self) -> &mut PrimaryKeystoreConfigBuilder
Sourcepub fn ctor(&mut self) -> &mut CTorKeystoreConfigBuilder
pub fn ctor(&mut self) -> &mut CTorKeystoreConfigBuilder
Return a mutable reference to the inner builder for ctor.
ctor
Optionally configure C Tor keystores for arti to use.
Note: The keystores listed here are read-only (keys are only
ever written to the primary keystore, configured in
storage.keystore.primary).
Each C Tor keystore must have a unique identifier.
It is an error to configure multiple keystores with the same KeystoreId.
Sourceimpl ArtiKeystoreConfigBuilder
impl ArtiKeystoreConfigBuilder
Sourcepub fn build(&self) -> Result<ArtiKeystoreConfig, ConfigBuildError>
pub fn build(&self) -> Result<ArtiKeystoreConfig, ConfigBuildError>
Try to construct a new ArtiKeystoreConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl ArtiKeystoreConfigBuilder
impl ArtiKeystoreConfigBuilder
Sourcepub fn ctor_service(
&mut self,
builder: CTorServiceKeystoreConfigBuilder,
) -> &mut Self
pub fn ctor_service( &mut self, builder: CTorServiceKeystoreConfigBuilder, ) -> &mut Self
Add a CTorServiceKeystoreConfigBuilder to this builder.