pub trait RawKeySpecifierComponentParser {
// Required method
fn parse(&mut self, comp: &Slug) -> RawComponentParseResult;
}Expand description
Trait for parsing a path component, used by parse_arti_path
Implemented for Option<impl KeySpecifierComponent>,
and guarantees to fill in the Option if it succeeds.
Also implemented for &str: just checks that the string is right,
(and, doesn’t modify *self).
Required Methods
Sourcefn parse(&mut self, comp: &Slug) -> RawComponentParseResult
fn parse(&mut self, comp: &Slug) -> RawComponentParseResult
Check that comp is as expected, and store any results in self.