pub trait CertSpecifierPattern {
type SubjectKeySpecifierPattern: KeySpecifierPattern;
// Required methods
fn new_any() -> Self
where Self: Sized;
fn arti_pattern(&self) -> Result<KeyPathPattern, Bug>;
}Expand description
A pattern specifying some or all of a kind of certificate
Generally implemented on SomeCertSpecifierPattern by applying
#[derive_deftly(CertSpecifier)
to SomeCertSpecifier.
Required Associated Types
Sourcetype SubjectKeySpecifierPattern: KeySpecifierPattern
type SubjectKeySpecifierPattern: KeySpecifierPattern
The key specifier pattern of the subject key.
Used to build the first part of the certificate specifier pattern (certificate paths consist of the ArtiPath of its subject key, followed by the cert denotators)
Required Methods
Sourcefn new_any() -> Selfwhere
Self: Sized,
fn new_any() -> Selfwhere
Self: Sized,
Obtain a pattern template that matches all certs of this type.
The pattern consists of the KeySpecifierPattern::new_any
of the SubjectKeySpecifierPattern, followed by a pattern
that matches all the certificate denotators, if there are any.
Sourcefn arti_pattern(&self) -> Result<KeyPathPattern, Bug>
fn arti_pattern(&self) -> Result<KeyPathPattern, Bug>
Get a KeyPathPattern that can match the ArtiPaths
of some or all the keys of this type.