pub trait KeySpecifierPattern {
// Required methods
fn new_any() -> Self
where Self: Sized;
fn arti_pattern(&self) -> Result<KeyPathPattern, Bug>;
}Expand description
A pattern specifying some or all of a kind of key
Generally implemented on SomeKeySpecifierPattern by
applying
#[derive_deftly(KeySpecifier)
to SomeKeySpecifier.
Required Methods
Sourcefn new_any() -> Selfwhere
Self: Sized,
fn new_any() -> Selfwhere
Self: Sized,
Obtain a pattern template that matches all keys of this type.
Sourcefn arti_pattern(&self) -> Result<KeyPathPattern, Bug>
fn arti_pattern(&self) -> Result<KeyPathPattern, Bug>
Get a KeyPathPattern that can match the ArtiPaths
of some or all the keys of this type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".